==> react-formbuild-component-2.0.4.tgz: package/doc/examples/json/select.js <==
const select = [
    {
        title: 'Date Picker Test',
        showCaptcha: false,
        buttons: [
            {
                name: 'submit',
                label: 'Enviar',
                type: 'button',
                color: 'primary', // or a HexColor
                action: 'isSubmit' // or isSetChapter or isCancel
            }
        ],
        fields: [

            {
                id: 'select',
                name: 'select',
                label: 'Select',
                type: 'select',
                onSubmit: null,
                options: ['Option 1', 'Option 2', 'Or You can Use Constants'],
                isSearching: false,
                supportsWriteOthers: false,
                source: {
                    query: {
                        search: '?fvalue',
                        options: '&fname=name&ftype=like&stype=S',
                        endpoint: `${ENDPOINT}/api/location`
                        //remember that the service needs to know what query.search is so it can hardcode = + e
                        // e === the value of the input so it can search. ! the e.length === searchAmount
                        //parameters = query.search + '=' + e + query.options
                        //return Http.get(`${query.endpoint}${parameters}`, token);
                    },
                    // WARNING unexpected behavior of this reducer when used as function outside of FormBuilder
                    reducer: result => { //reducer function takes care of building the object that the select component consumes.
                        if (result.message) { //if the api returns with a 404  fills the option with the 404 message
                            return {label: result.message, value: null};
                        }
                        return ({ // here you can build the label that shows up in the select component, in this case several fields are mixed together to make a new string
                            label: `${result.name} - cp: ${result.cp} - ${result.province.name}`,
                            value: result.id
                        });
                    }
                },
                validateOnChange: value => {
                    const isValid = {status: 'valid', message: 'Picked an option'};
                    if (!value || value.value === null) {
                        isValid.status = 'invalid';
                        isValid.message = 'No option as been picked';
                    }
                    return isValid;
                },
                searchAmount: 4, // Minimun amount of letters before making a http request
                token: 'If the source requires a Authorization'
            }
        ]
    }
]

export default select;

==> react-formbuild-component-3.0.3.tgz: package/doc/examples/json/select.js <==
const select = [
    {
        title: 'Date Picker Test',
        showCaptcha: false,
        buttons: [
            {
                name: 'submit',
                label: 'Enviar',
                type: 'button',
                color: 'primary', // or a HexColor
                action: 'isSubmit', // or isSetChapter or isCancel
                executeSetFocus: false // true or false
            }
        ],
        fields: [

            {
                id: 'select',
                name: 'select',
                label: 'Select',
                type: 'select',
                onSubmit: null,
                options: ['Option 1', 'Option 2', 'Or You can Use Constants'],
                isSearching: false,
                supportsWriteOthers: false,
                source: {
                    query: {
                        search: '?fvalue',
                        options: '&fname=name&ftype=like&stype=S',
                        endpoint: `${ENDPOINT}/api/location`
                        //remember that the service needs to know what query.search is so it can hardcode = + e
                        // e === the value of the input so it can search. ! the e.length === searchAmount
                        //parameters = query.search + '=' + e + query.options
                        //return Http.get(`${query.endpoint}${parameters}`, token);
                    },
                    // WARNING unexpected behavior of this reducer when used as function outside of FormBuilder
                    reducer: result => { //reducer function takes care of building the object that the select component consumes.
                        if (result.message) { //if the api returns with a 404  fills the option with the 404 message
                            return {label: result.message, value: null};
                        }
                        return ({ // here you can build the label that shows up in the select component, in this case several fields are mixed together to make a new string
                            label: `${result.name} - cp: ${result.cp} - ${result.province.name}`,
                            value: result.id
                        });
                    }
                },
                validateOnChange: value => {
                    const isValid = {status: 'valid', message: 'Picked an option'};
                    if (!value || value.value === null) {
                        isValid.status = 'invalid';
                        isValid.message = 'No option as been picked';
                    }
                    return isValid;
                },
                searchAmount: 4, // Minimun amount of letters before making a http request
                token: 'If the source requires a Authorization'
            }
        ]
    }
]

export default select;
